Module cache

Module cache 

Structs

ArrayCache
Contains an array of pre-computed values for a given problem and value of rho
SingleCache
Contains all pre-computed values for a given problem and value of rho

Enums

Error
Errors that can occur during cache setup

Traits

Cache