Constraint

Struct Constraint 

pub struct Constraint<T: RealField + Copy, P: ProjectMulti<T, N, H>, const N: usize, const H: usize> {
    pub max_prim_residual: T,
    pub max_dual_residual: T,
    /* private fields */
}
A Constraint consists of a projection function and a set of associated slack and dual variables.

Fields

max_prim_residual: Tmax_dual_residual: T

Implementations

Source

impl<T: RealField + Copy, const N: usize, const H: usize, P: ProjectMulti<T, N, H>> Constraint<T, P, N, H>

pub fn new(projector: P) -> Self

Construct a new Constraint from the provided [Project] type.

pub fn projector_mut(&mut self) -> &mut P

Get a mutable reference to the projector. Allows for modifying or completely swapping the projector at runtime.

pub fn reset(&mut self)

Reset all internal state of this constraint

pub fn constrain( &mut self, compute_residuals: bool, points: &SMatrix<T, N, H>, reference: Option<&SMatrix<T, N, H>>, scratch: &mut SMatrix<T, N, H>, )

Constrains the set of points, and if compute_residuals == true, computes the maximum primal and dual residuals