pub struct FixedPolicy<T, const NX: usize, const NU: usize> { /* private fields */ }Expand description
Contains all pre-computed values for a given problem and value of rho.
Implementations
Sourceimpl<T, const NX: usize, const NU: usize> FixedPolicy<T, NX, NU>
impl<T, const NX: usize, const NU: usize> FixedPolicy<T, NX, NU>
Sourcepub fn new(
rho: T,
iters: usize,
A: &SMatrix<T, NX, NX>,
B: &SMatrix<T, NX, NU>,
Q: &SMatrix<T, NX, NX>,
R: &SMatrix<T, NU, NU>,
S: &SMatrix<T, NX, NU>,
) -> Result<Self, Error>
pub fn new( rho: T, iters: usize, A: &SMatrix<T, NX, NX>, B: &SMatrix<T, NX, NU>, Q: &SMatrix<T, NX, NX>, R: &SMatrix<T, NU, NU>, S: &SMatrix<T, NX, NU>, ) -> Result<Self, Error>
Create a new FixedPolicy.
Errors
If the calculated LQR gain is not invertible, or any of the calculated values are not normal.