pub struct CircularCone<T: RealField + Copy, const D: usize> { /* private fields */ }Expand description
A circular cone projection
Implementations
Sourceimpl<T: RealField + Copy, const D: usize> CircularCone<T, D>
impl<T: RealField + Copy, const D: usize> CircularCone<T, D>
Sourcepub fn new() -> CircularCone<T, D>
pub fn new() -> CircularCone<T, D>
Create a new CircularCone projector with default values.
Sourcepub fn axis(self, axis: impl Into<SVector<T, D>>) -> Self
pub fn axis(self, axis: impl Into<SVector<T, D>>) -> Self
Set the axis along the center of the cone.
Sourcepub fn mut_axis(&mut self, axis: impl Into<SVector<T, D>>)
pub fn mut_axis(&mut self, axis: impl Into<SVector<T, D>>)
Set the axis along the center of the cone.
Sourcepub fn vertex(self, vertex: impl Into<SVector<T, D>>) -> Self
pub fn vertex(self, vertex: impl Into<SVector<T, D>>) -> Self
Set the coordinate of the cones vertex / tip.
Sourcepub fn mut_vertex(&mut self, vertex: impl Into<SVector<T, D>>)
pub fn mut_vertex(&mut self, vertex: impl Into<SVector<T, D>>)
Set the coordinate of the cones vertex / tip.