pub trait Project<T, const N: usize, const H: usize> {
// Required method
fn project(&self, points: &mut SMatrix<T, N, H>);
}Expand description
Can project a series of points into their feasible region.
pub trait Project<T, const N: usize, const H: usize> {
// Required method
fn project(&self, points: &mut SMatrix<T, N, H>);
}Can project a series of points into their feasible region.