pub trait ProjectMulti<T, const D: usize, const H: usize> {
// Required method
fn project_multi(&self, points: &mut SMatrix<T, D, H>);
}Expand description
Can project a multiple points into their feasible region.
pub trait ProjectMulti<T, const D: usize, const H: usize> {
// Required method
fn project_multi(&self, points: &mut SMatrix<T, D, H>);
}Can project a multiple points into their feasible region.