TinyMpc

Struct TinyMpc 

pub struct TinyMpc<T, CACHE: Cache<T, NX, NU>, const NX: usize, const NU: usize, const HX: usize, const HU: usize> {
    pub config: Config<T>,
    /* private fields */
}

Fields

config: Config<T>

Implementations

Source

impl<T, C: Cache<T, NX, NU>, const NX: usize, const NU: usize, const HX: usize, const HU: usize> TinyMpc<T, C, NX, NU, HX, HU>
where T: Scalar + RealField + Copy,

pub fn new(A: SMatrix<T, NX, NX>, B: SMatrix<T, NX, NU>, cache: C) -> Self

pub fn with_sys(self, sys: LtiFn<T, NX, NU>) -> Self

pub fn initial_condition( &mut self, x_now: SVector<T, NX>, ) -> Problem<'_, T, C, NX, NU, HX, HU>

pub fn solve<'a>( &'a mut self, x_now: SVector<T, NX>, x_ref: Option<&'a SMatrix<T, NX, HX>>, u_ref: Option<&'a SMatrix<T, NU, HU>>, x_con: Option<&mut [Constraint<T, impl Project<T, NX, HX>, NX, HX>]>, u_con: Option<&mut [Constraint<T, impl Project<T, NU, HU>, NU, HU>]>, ) -> Solution<'a, T, NX, NU, HX, HU>

pub fn get_num_iters(&self) -> usize

Get the number of iterations of the previous solve

pub fn get_u_at(&self, i: usize) -> SVector<T, NU>

Get the system input u for the time i

pub fn get_u(&self) -> SVector<T, NU>

Get the system input u for the current time

pub fn get_x_matrix(&self) -> &SMatrix<T, NX, HX>

Get reference to matrix containing state predictions

pub fn get_u_matrix(&self) -> &SMatrix<T, NU, HU>

Get reference to matrix containing input predictions