pub struct Constraint<T, P: Project<T, N, H>, const N: usize, const H: usize> {
pub max_prim_residual: T,
pub max_dual_residual: T,
/* private fields */
}Expand description
A Constraint consists of a projection function and a set of associated slack and dual variables.
Fields
max_prim_residual: Tmax_dual_residual: TImplementations
Sourceimpl<T: RealField + Copy, const N: usize, const H: usize, P: Project<T, N, H>> Constraint<T, P, N, H>
impl<T: RealField + Copy, const N: usize, const H: usize, P: Project<T, N, H>> Constraint<T, P, N, H>
Sourcepub fn new(projector: P) -> Self
pub fn new(projector: P) -> Self
Construct a new Constraint from the provided Project type.
Sourcepub fn projector_mut(&mut self) -> &mut P
pub fn projector_mut(&mut self) -> &mut P
Get a mutable reference to the projector. Allows for modifying or completely swapping the projector at runtime.