pub trait ProjectExt<T: RealField + Copy, const N: usize, const H: usize>: Project<T, N, H> + Sized {
// Provided methods
fn dynamic(&self) -> &dyn Project<T, N, H> { ... }
fn constraint(&self) -> Constraint<T, &Self, N, H> { ... }
fn dyn_constraint(&self) -> DynConstraint<'_, T, N, H> { ... }
}Expand description
Extension trait for types implementing Project to convert it directly
into a constraint with associated dual and slack variables.
Provided Methods
fn dynamic(&self) -> &dyn Project<T, N, H>
fn constraint(&self) -> Constraint<T, &Self, N, H>
fn dyn_constraint(&self) -> DynConstraint<'_, T, N, H>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.